/* arduino_radar
 *
 * Ultrahangos "radar" egy szervo és egy HC-SR04 szenzor
 * felhasználásával. A szervo segítségével az ultrahangos 
 * távolságmérőt oda-vissza forgatjuk 15 és 165 fok között,
 * s közben mérjük a távolságot minden szögnél.in
 * A mérési adatokat (a fokokban mért szög és a cm-ben
 * mért távolságot) a soros porton kiíratjuk "szög,táv."
 * formában. A pont az adatok szinkronizálásához kell.
 * A soroa portot 9600 baudra konfiguráljuk.
 *
 * A programban most kikommentelt sorok akkor kellenek, ha 
 * a HC-SR04 szenzort tartó szerelvény egy második, "bólogatást"
 * végző szervóval is rendelkezik. Ezt mi az A5 lábra kötöttük
 * (Multifunction shieldnél ez állt rendelkezésre). 
 *
 * Hardver feltételek:
 * - Szervo vezérlőjel - D9
 * - HC-SR04 Trigger   - D5
 * - HC-SR04 Echo      - D6
 *
 * A program forrása: https://create.arduino.cc/projecthub/Yug_Ajmera/radar-sonar-using-processing-3-7302c6
 * Az eredeti programot némileg módosította: I.Cserny (hobbi@cspista.hu) 
 * 
 */
#include <Servo.h>
#define trigPin 5
#define echoPin 6

Servo s1;
// Servo s2;

int angle= 90;                       // Kezdő irány (fok)
int angleStep = 1;                   // szög léptetés (fok)
int calDist(void);

void setup() {
  Serial.begin(9600);
  pinMode(trigPin, OUTPUT);
  pinMode(echoPin, INPUT);
  s1.attach(9);
//  s2.attach(A5);
//  s2.write(1350);
}

void loop() {
  s1.write(angle);                  // Irány beállítás
  delay(50);                        // Várunk egy picit
  int distance = calDist();         // Távolságmérés
  Serial.print(180-angle);          // Szög kiírása (fordítással)
  Serial.print(",");                // Elválasztó karakter
  Serial.print(distance);           // Távolság cm-ben
  Serial.print(".");                // szinkronizáló karakter
  if(angle==15 || angle==165)       // Határ elérésekor
    angleStep = - angleStep;        // megfordítjuk az irányt
  angle = angle + angleStep;        // Szög léptetése
}

int calDist() {
  int duration;
  digitalWrite(trigPin, HIGH);      // Start Trigger
  delayMicroseconds(10);            // 10 us késleltetés
  digitalWrite(trigPin, LOW);       // Stop trigger 
  duration = pulseIn(echoPin,HIGH); // Impulzus-szélesség mérés     
  int distance = duration/58.82;    // Kiszámoljuk a távolságot
  return distance;                  // A cm-ben mért távolság 
}
